@@ -1,9 +1,16 @@
-deprecate_arg_warn <- function(old, new) {
-  if (!is.null(old) && old != "DEPRECATED")
+deprecate_arg_warn <- function(old, new = NULL) {
+  has_old <- !is.null(old) && old != "DEPRECATED"
+  has_new <- is.null(new) || isFALSE(new)
+  if (has_old && has_new) {
     warning_glue("`{substitute(old)}` is deprecated. Please use `{substitute(new)}` instead.")
+  }else if(has_old){
+    warning_glue("`{substitute(old)}` is deprecated.")
+  }
 }
 
-deprecate_arg_stop <- function(old, new) {
+deprecate_arg_stop <- function(old, new = NULL) {
+  if(old == "DEPRECATED" && is.null(new))
+    warning_glue("`{substitute(old)}` is deprecated.")
   if (!is.null(old) && old != "DEPRECATED")
     stop_glue("`{substitute(old)}` is deprecated. Please use `{substitute(new)}` instead.")
 }
