@@ -1,5 +1,8 @@
 # TODO revisit this function if you have time
 
+#' Calculate p-values
+#'
+#'
 #' Calculate p-values from `distr` object
 #'
 #' @param x A `radf_obj` object.
@@ -9,31 +12,37 @@
 #' @importFrom tidyr nest spread
 #' @importFrom purrr when map2_dbl
 #' @importFrom dplyr group_by
+#' @keywords internal
 #' @examples
 #'
+#'
 #' \dontrun{
 #' radf_psy1 <- radf(sim_psy1(100))
 #'
 #' calc_pvalue(radf_psy1)
 #'
 #' # Using the Wild-Bootstrapped
-#' wb_psy1 <- wb_distr(sim_psy1(100))
+#' wb_psy1 <- radf_wb_distr(sim_psy1(100))
 #'
 #' calc_pvalue(radf_psy1, wb_psy1)
+#'
+#' sb_psy1 <- radf_sb_distr(sim_data)
+#'
+#' calc_pvalue(radf(sim_data), sb_psy1)
+#'
 #' }
 calc_pvalue <- function(x, distr = NULL) {
 
-  assert_class(x, "radf")
+  assert_class(x, "radf_obj")
   if (is.null(distr)) {
     message_glue("Using `radf_mc_distr` for `distr`.")
     distr <- radf_mc_distr(attr(x, "n"), minw = attr(x, "minw"))
   }
-  assert_class(distr, "distr"
-  )
+  assert_class(distr, "radf_distr")
   if (is_sb(distr)) {
     tbl_x <- tidy(x, panel = TRUE) %>%
       mutate(id = "panel", stat = "gsadf_panel") %>%
-      nest(value_x = panel)
+      nest(value_x = gsadf_panel)
   } else{
     tbl_x <- tidy(x) %>%
       gather(stat, value_x, -id) %>%
@@ -61,8 +70,8 @@ calc_pvalue <- function(x, distr = NULL) {
     mutate(pval = map2_dbl(value_x, value_y, xy_pvalue)) %>%
     select(id, stat, pval) %>%
     spread(stat, pval) %>%
-    when(is_sb(distr) ~ ., ~ select(., id, adf, sadf, gsadf)) %>%
-    add_class("pval")
+    when(is_sb(distr) ~ ., ~ select(., id, adf, sadf, gsadf))
+
 }
 
 
